@@ -46,8 +46,6 @@ sub apply {
 	) . $post;
     }gsex;
 
-    $$ref =~ s{^=encoding\s+\S+\s*$}{\n}mg;
-
     $$ref = '#line 1 "' . ($filename) . "\"\n" . $$ref
         if length $filename;
     $$ref =~ s/^#line 1 (.*\n)(#!.*\n)/$2#line 2 $1/g;
@@ -64,8 +62,6 @@ L<PAR::Filter>
 
 Audrey Tang E<lt>cpan@audreyt.orgE<gt>
 
-Steffen Mueller E<lt>smueller@cpan.orgE<gt>
-
 L<http://par.perl.org/> is the official PAR website.  You can write
 to the mailing list at E<lt>par@perl.orgE<gt>, or send an empty mail to
 E<lt>par-subscribe@perl.orgE<gt> to participate in the discussion.
@@ -74,7 +70,7 @@ Please submit bug reports to E<lt>bug-par@rt.cpan.orgE<gt>.
 
 =head1 COPYRIGHT
 
-Copyright 2003-2008 Audrey Tang E<lt>cpan@audreyt.orgE<gt>,
+Copyright 2003, 2004, 2005, 2006 by Audrey Tang E<lt>cpan@audreyt.orgE<gt>.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
